summaryrefslogtreecommitdiff
path: root/README.cmake
diff options
context:
space:
mode:
authorSimon McVittie <simon.mcvittie@collabora.co.uk>2012-01-04 19:39:54 +0000
committerSimon McVittie <simon.mcvittie@collabora.co.uk>2012-08-13 19:51:42 +0100
commit05b0b9e65b6a58f0b0cb56d6ee8cf100061250b3 (patch)
treef49bfef3f3bcda7d573e70ad704a8d7b66372ff8 /README.cmake
parent9436816175060f038af9c06cf135246f955f9ed4 (diff)
downloaddbus-05b0b9e65b6a58f0b0cb56d6ee8cf100061250b3.tar.gz
cmake: use the same default system bus address as for autotools
The system bus is unsupported (and rather meaningless) on Windows anyway, so we can use anything. Also, make it clear that it has to be a "specific" address that can be listened on *and* connected to, like unix:path=/xxx - a listen-only address like unix:tmpdir=/xxx or nonce-tcp: would not be suitable. Bug: https://bugs.freedesktop.org/show_bug.cgi?id=38201 Reviewed-by: David Zeuthen <davidz@redhat.com>
Diffstat (limited to 'README.cmake')
-rw-r--r--README.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/README.cmake b/README.cmake
index 5feaf551..0e923356 100644
--- a/README.cmake
+++ b/README.cmake
@@ -80,7 +80,7 @@ Configuration flags
When using the cmake build system the dbus-specific configuration flags that can be given
to the cmake program are these (use -D<key>=<value> on command line). The listed values
-are the defaults.
+are the defaults (in a typical build - some are platform-specific).
// Choose the type of build, options are: None(CMAKE_CXX_FLAGS or
// CMAKE_C_FLAGS used) Debug Release RelWithDebInfo MinSizeRel.
@@ -132,8 +132,8 @@ DBUS_INSTALL_SYSTEM_LIBS:BOOL=OFF
// session bus default address
DBUS_SESSION_BUS_DEFAULT_ADDRESS:STRING=nonce-tcp:
-// system bus default address
-DBUS_SYSTEM_BUS_DEFAULT_ADDRESS:STRING=nonce-tcp:
+// system bus default address (only useful on Unix)
+DBUS_SYSTEM_BUS_DEFAULT_ADDRESS:STRING=unix:path=/var/run/dbus/system_bus_socket
// Use atomic integer implementation for 486
DBUS_USE_ATOMIC_INT_486:BOOL=OFF